import { Component, ComponentFactoryResolver, Input, NgModule, ViewContainerRef, ViewEncapsulation } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpClient, HttpHeaders, HttpParams } from '@angular/common/http';
import { EuBpmnService } from 'ng2-easyui.core';
import * as BpmnModeler from 'bpmn-js/lib/Modeler';
import BpmnModeler__default from 'bpmn-js/lib/Modeler';
import * as BpmnViewer from 'bpmn-js/lib/Viewer';
import BpmnViewer__default from 'bpmn-js/lib/Viewer';
import * as propertiesPanelModule from 'bpmn-js-properties-panel';
import propertiesPanelModule__default from 'bpmn-js-properties-panel';
import * as propertiesProviderModule from 'bpmn-js-properties-panel/lib/provider/camunda';
import propertiesProviderModule__default from 'bpmn-js-properties-panel/lib/provider/camunda';
import { Headers, Http, RequestOptions, URLSearchParams } from '@angular/http';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/observable/forkJoin';
import { assign, each } from 'lodash';
import * as _ from 'lodash';
import svgAppend from 'tiny-svg/lib/append';
import svgAttr from 'tiny-svg/lib/attr';
import svgCreate from 'tiny-svg/lib/create';
import domQuery from 'min-dom/lib/query';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var CamundaModdleDescriptor = {
    "name": "Camunda",
    "uri": "http://camunda.org/schema/1.0/bpmn",
    "prefix": "camunda",
    "xml": {
        "tagAlias": "lowerCase"
    },
    "associations": [],
    "types": [
        {
            "name": "InOutBinding",
            "superClass": [
                "Element"
            ],
            "isAbstract": true,
            "properties": [
                {
                    "name": "source",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "sourceExpression",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "target",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "businessKey",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "local",
                    "isAttr": true,
                    "type": "Boolean",
                    "default": false
                },
                {
                    "name": "variables",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "In",
            "superClass": [
                "InOutBinding"
            ]
        },
        {
            "name": "Out",
            "superClass": [
                "InOutBinding"
            ]
        },
        {
            "name": "AsyncCapable",
            "isAbstract": true,
            "extends": [
                "bpmn:Activity",
                "bpmn:Gateway",
                "bpmn:Event"
            ],
            "properties": [
                {
                    "name": "async",
                    "isAttr": true,
                    "type": "Boolean",
                    "default": false
                },
                {
                    "name": "asyncBefore",
                    "isAttr": true,
                    "type": "Boolean",
                    "default": false
                },
                {
                    "name": "asyncAfter",
                    "isAttr": true,
                    "type": "Boolean",
                    "default": false
                },
                {
                    "name": "exclusive",
                    "isAttr": true,
                    "type": "Boolean",
                    "default": true
                }
            ]
        },
        {
            "name": "JobPriorized",
            "isAbstract": true,
            "extends": [
                "bpmn:Process",
                "camunda:AsyncCapable"
            ],
            "properties": [
                {
                    "name": "jobPriority",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "SignalEventDefinition",
            "isAbstract": true,
            "extends": [
                "bpmn:SignalEventDefinition"
            ],
            "properties": [
                {
                    "name": "async",
                    "isAttr": true,
                    "type": "Boolean",
                    "default": false
                }
            ]
        },
        {
            "name": "ErrorEventDefinition",
            "isAbstract": true,
            "extends": [
                "bpmn:ErrorEventDefinition"
            ],
            "properties": [
                {
                    "name": "errorCodeVariable",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "errorMessageVariable",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "PotentialStarter",
            "superClass": [
                "Element"
            ],
            "properties": [
                {
                    "name": "resourceAssignmentExpression",
                    "type": "bpmn:ResourceAssignmentExpression"
                }
            ]
        },
        {
            "name": "FormSupported",
            "isAbstract": true,
            "extends": [
                "bpmn:StartEvent",
                "bpmn:UserTask"
            ],
            "properties": [
                {
                    "name": "formHandlerClass",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "formKey",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "Initiator",
            "isAbstract": true,
            "extends": ["bpmn:StartEvent"],
            "properties": [
                {
                    "name": "initiator",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "ScriptTask",
            "isAbstract": true,
            "extends": [
                "bpmn:ScriptTask"
            ],
            "properties": [
                {
                    "name": "resultVariable",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "resource",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "Process",
            "isAbstract": true,
            "extends": [
                "bpmn:Process"
            ],
            "properties": [
                {
                    "name": "candidateStarterGroups",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "candidateStarterUsers",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "versionTag",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "EscalationEventDefinition",
            "isAbstract": true,
            "extends": [
                "bpmn:EscalationEventDefinition"
            ],
            "properties": [
                {
                    "name": "escalationCodeVariable",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "FormalExpression",
            "isAbstract": true,
            "extends": [
                "bpmn:FormalExpression"
            ],
            "properties": [
                {
                    "name": "resource",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "Assignable",
            "extends": ["bpmn:UserTask"],
            "properties": [
                {
                    "name": "assignee",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "candidateUsers",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "candidateGroups",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "dueDate",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "followUpDate",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "priority",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "CallActivity",
            "extends": ["bpmn:CallActivity"],
            "properties": [
                {
                    "name": "calledElementBinding",
                    "isAttr": true,
                    "type": "String",
                    "default": "latest"
                },
                {
                    "name": "calledElementVersion",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "calledElementTenantId",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "caseRef",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "caseBinding",
                    "isAttr": true,
                    "type": "String",
                    "default": "latest"
                },
                {
                    "name": "caseVersion",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "caseTenantId",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "variableMappingClass",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "variableMappingDelegateExpression",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "ServiceTaskLike",
            "extends": [
                "bpmn:ServiceTask",
                "bpmn:BusinessRuleTask",
                "bpmn:SendTask",
                "bpmn:MessageEventDefinition"
            ],
            "properties": [
                {
                    "name": "expression",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "class",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "delegateExpression",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "resultVariable",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "DmnCapable",
            "extends": [
                "bpmn:BusinessRuleTask"
            ],
            "properties": [
                {
                    "name": "decisionRef",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "decisionRefBinding",
                    "isAttr": true,
                    "type": "String",
                    "default": "latest"
                },
                {
                    "name": "decisionRefVersion",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "mapDecisionResult",
                    "isAttr": true,
                    "type": "String",
                    "default": "resultList"
                },
                {
                    "name": "decisionRefTenantId",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "ExternalCapable",
            "extends": [
                "camunda:ServiceTaskLike"
            ],
            "properties": [
                {
                    "name": "type",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "topic",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "TaskPriorized",
            "extends": [
                "bpmn:Process",
                "camunda:ExternalCapable"
            ],
            "properties": [
                {
                    "name": "taskPriority",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "Properties",
            "superClass": [
                "Element"
            ],
            "properties": [
                {
                    "name": "values",
                    "type": "Property",
                    "isMany": true
                }
            ]
        },
        {
            "name": "Property",
            "superClass": [
                "Element"
            ],
            "properties": [
                {
                    "name": "id",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "name",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "value",
                    "type": "String",
                    "isAttr": true
                }
            ]
        },
        {
            "name": "Connector",
            "superClass": [
                "Element"
            ],
            "properties": [
                {
                    "name": "inputOutput",
                    "type": "InputOutput"
                },
                {
                    "name": "connectorId",
                    "type": "String"
                }
            ]
        },
        {
            "name": "InputOutput",
            "superClass": [
                "Element"
            ],
            "properties": [
                {
                    "name": "inputOutput",
                    "type": "InputOutput"
                },
                {
                    "name": "connectorId",
                    "type": "String"
                },
                {
                    "name": "inputParameters",
                    "isMany": true,
                    "type": "InputParameter"
                },
                {
                    "name": "outputParameters",
                    "isMany": true,
                    "type": "OutputParameter"
                }
            ]
        },
        {
            "name": "InputOutputParameter",
            "properties": [
                {
                    "name": "name",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "value",
                    "isBody": true,
                    "type": "String"
                },
                {
                    "name": "definition",
                    "type": "InputOutputParameterDefinition"
                }
            ]
        },
        {
            "name": "InputOutputParameterDefinition",
            "isAbstract": true
        },
        {
            "name": "List",
            "superClass": ["InputOutputParameterDefinition"],
            "properties": [
                {
                    "name": "items",
                    "isMany": true,
                    "type": "InputOutputParameterDefinition"
                }
            ]
        },
        {
            "name": "Map",
            "superClass": ["InputOutputParameterDefinition"],
            "properties": [
                {
                    "name": "entries",
                    "isMany": true,
                    "type": "Entry"
                }
            ]
        },
        {
            "name": "Entry",
            "properties": [
                {
                    "name": "key",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "value",
                    "isBody": true,
                    "type": "String"
                },
                {
                    "name": "definition",
                    "type": "InputOutputParameterDefinition"
                }
            ]
        },
        {
            "name": "Value",
            "superClass": [
                "InputOutputParameterDefinition"
            ],
            "properties": [
                {
                    "name": "id",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "name",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "value",
                    "isBody": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "Script",
            "superClass": ["InputOutputParameterDefinition"],
            "properties": [
                {
                    "name": "scriptFormat",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "resource",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "value",
                    "isBody": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "Field",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "name",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "expression",
                    "type": "String"
                },
                {
                    "name": "stringValue",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "string",
                    "type": "String"
                }
            ]
        },
        {
            "name": "InputParameter",
            "superClass": ["InputOutputParameter"]
        },
        {
            "name": "OutputParameter",
            "superClass": ["InputOutputParameter"]
        },
        {
            "name": "Collectable",
            "isAbstract": true,
            "extends": ["bpmn:MultiInstanceLoopCharacteristics"],
            "superClass": ["camunda:AsyncCapable"],
            "properties": [
                {
                    "name": "collection",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "elementVariable",
                    "isAttr": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "FailedJobRetryTimeCycle",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "body",
                    "isBody": true,
                    "type": "String"
                }
            ]
        },
        {
            "name": "ExecutionListener",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "expression",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "class",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "delegateExpression",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "event",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "script",
                    "type": "Script"
                },
                {
                    "name": "fields",
                    "type": "Field",
                    "isMany": true
                }
            ]
        },
        {
            "name": "TaskListener",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "expression",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "class",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "delegateExpression",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "event",
                    "isAttr": true,
                    "type": "String"
                },
                {
                    "name": "script",
                    "type": "Script"
                },
                {
                    "name": "fields",
                    "type": "Field",
                    "isMany": true
                }
            ]
        },
        {
            "name": "FormProperty",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "id",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "name",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "type",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "required",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "readable",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "writable",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "variable",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "expression",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "datePattern",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "default",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "values",
                    "type": "Value",
                    "isMany": true
                }
            ]
        },
        {
            "name": "FormData",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "fields",
                    "type": "FormField",
                    "isMany": true
                },
                {
                    "name": "businessKey",
                    "type": "String",
                    "isAttr": true
                }
            ]
        },
        {
            "name": "FormField",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "id",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "label",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "type",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "datePattern",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "defaultValue",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "properties",
                    "type": "Properties"
                },
                {
                    "name": "validation",
                    "type": "Validation"
                },
                {
                    "name": "values",
                    "type": "Value",
                    "isMany": true
                }
            ]
        },
        {
            "name": "Validation",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "constraints",
                    "type": "Constraint",
                    "isMany": true
                }
            ]
        },
        {
            "name": "Constraint",
            "superClass": ["Element"],
            "properties": [
                {
                    "name": "name",
                    "type": "String",
                    "isAttr": true
                },
                {
                    "name": "config",
                    "type": "String",
                    "isAttr": true
                }
            ]
        }
    ],
    "emumerations": []
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var BpmnEditorComponent = (function () {
    function BpmnEditorComponent(http, euBpmnService) {
        this.http = http;
        this.euBpmnService = euBpmnService;
        this.model = {
            params: {}
        };
    }
    /**
     * @return {?}
     */
    BpmnEditorComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        // this.model.params.type = 'add'
        if (this.model.params.processDefId != undefined
            || this.model.params.type == "add") {
            // (require as any).ensure([], require => {
            //     // debugger
            //     let BpmnModeler = require('bpmn-js/lib/Modeler')
            //     let BpmnViewer = require('bpmn-js/lib/Viewer')
            //     let propertiesPanelModule = require('bpmn-js-properties-panel')
            //     let propertiesProviderModule = require('bpmn-js-properties-panel/lib/provider/camunda')
            //     this.initBpmn(BpmnModeler, BpmnViewer, propertiesPanelModule, propertiesProviderModule)
            // });
            this.initBpmn(BpmnModeler, BpmnViewer, propertiesPanelModule, propertiesProviderModule);
        }
    };
    /**
     * @return {?}
     */
    BpmnEditorComponent.prototype.initConfigListener = /**
     * @return {?}
     */
    function () {
        // var overlayHtml = $('<div><ul class="menu">'+
        // '<li class="menu-item">'+
        //     '<button type="button" class="menu-btn">'+
        //         '<i class="fa fa-folder-open"></i>'+
        //         '<span class="menu-text">Open</span>'+
        //     '</button>'+
        // '</li>'+
        // '</ul></div>');
        // var formSetHtml = $('<li class="menu-item">' +
        //     '<button type="button" class="menu-btn">' +
        //     '<i class="fa fa-th"></i>' +
        //     '<span class="menu-text">表单设置</span>' +
        //     '</button></li>')
        // var activitySetHtml = $('<li class="menu-item">' +
        //     '<button type="button" class="menu-btn">' +
        //     '<i class="fa fa-cog"></i>' +
        //     '<span class="menu-text">节点设置</span>' +
        //     '</button></li>')
        // var overlayHtml = $('<div class="menu">' +
        //     '</div>')
        // overlayHtml.append(formSetHtml)
        // overlayHtml.append(activitySetHtml)
        // // var overlayHtml = $('<div><ul class="menu">click!</ul></div>')
        // formSetHtml.click((e) => {
        //     this._overlays.remove({ element: this._curElement });
        //     this.modalService.open(
        //         this._modalContext,
        //         {
        //             comp: FormConfigComponent,
        //             title: '表单设置',
        //             width: '900px'
        //         },
        //         {
        //             params: this.model.params,
        //             curActivity: this._curElement
        //         },
        //         data => {
        //         }
        //     );
        // });
        // activitySetHtml.click((e) => {
        //     this._overlays.remove({ element: this._curElement });
        //     this.modalService.open(
        //         this._modalContext,
        //         {
        //             comp: ActivityConfigComponent,
        //             title: '节点设置',
        //             width: '800px'
        //         },
        //         {
        //             params: this.model.params,
        //             curActivity: this._curElement
        //         },
        //         data => {
        //         }
        //     );
        // });
        // if (this._bpmnModeler != undefined) {
        //     this._overlays = this._bpmnModeler.get('overlays');
        //     this._bpmnModeler.on('element.hover', (event) => {
        //         var element = event.element,
        //             moddle = this._bpmnModeler.get('moddle'),
        //             // the underlaying BPMN 2.0 element
        //             businessObject = element.businessObject
        //         var overlays = this._bpmnModeler.get('overlays');
        //         if (businessObject.$type == "bpmn:UserTask"
        //             || businessObject.$type == "bpmn:EndEvent"
        //             || businessObject.$type == "bpmn:StartEvent") {
        //             this._curElement = element
        //             overlays.remove({ element: element });
        //             // attach an overlay to a node
        //             overlays.add(element, {
        //                 position: {
        //                     bottom: 50,
        //                     right: 0
        //                 },
        //                 html: overlayHtml
        //             });
        //         }
        //         console.log("element hover", element.id)
        //         console.log("element type", businessObject.$type)
        //     })
        //     this._bpmnModeler.on('element.click', (event) => {
        //         var element = event.element
        //         var overlays = this._bpmnModeler.get('overlays');
        //         overlays.remove({ element: this._curElement });
        //         console.log("element click", element.id)
        //     })
        // }
    };
    /**
     * @param {?} BpmnModeler
     * @param {?} BpmnViewer
     * @param {?} propertiesPanelModule
     * @param {?} propertiesProviderModule
     * @return {?}
     */
    BpmnEditorComponent.prototype.initBpmn = /**
     * @param {?} BpmnModeler
     * @param {?} BpmnViewer
     * @param {?} propertiesPanelModule
     * @param {?} propertiesProviderModule
     * @return {?}
     */
    function (BpmnModeler$$1, BpmnViewer$$1, propertiesPanelModule$$1, propertiesProviderModule$$1) {
        var _this = this;
        if ((this.model.params.processDefId == undefined && this.model.params.type != "add")) {
            console.warn('没有流程信息');
            return;
        }
        // var windowl: any = window
        // var propertiesPanelModule = windowl.PropertiesPanelModule;
        // var propertiesProviderModule = windowl.PropertiesProviderModule;
        // var camundaModdleDescriptor = require("./camunda")
        // var BpmnModeler = windowl.BpmnJS;
        // var BpmnViewer = windowl.BpmnViewer;
        // var canvas = $('#js-canvas');
        // var canvas = document.querySelectorAll('#js-canvas')
        var /** @type {?} */ canvas = '#js-canvas';
        if (this.model.params.type == "add") {
            if (this._bpmnModeler == undefined) {
                // create modeler
                this._bpmnModeler = new BpmnModeler$$1({
                    container: canvas,
                    zoomScroll: { enabled: false },
                    propertiesPanel: {
                        parent: '#js-properties-panel'
                    },
                    additionalModules: [
                        propertiesPanelModule$$1,
                        propertiesProviderModule$$1
                    ],
                    moddleExtensions: {
                        // camunda: camundaModdleDescriptor.CamundaModdleDescriptor
                        camunda: CamundaModdleDescriptor
                    }
                });
            }
            var /** @type {?} */ initXml = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n                <definitions xmlns=\"http://www.omg.org/spec/BPMN/20100524/MODEL\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:bpmndi=\"http://www.omg.org/spec/BPMN/20100524/DI\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:activiti=\"http://activiti.org/bpmn\" targetNamespace=\"http://www.activiti.org/processdef\">\n                <process isExecutable=\"true\" id=\"" + this.model.params.key + "\"" + (this.model.params.name == undefined ? "" : " name=\"" + this.model.params.name + "\"") + " />\n                <bpmndi:BPMNDiagram id=\"BPMNDiagram_test\">\n                    <bpmndi:BPMNPlane id=\"BPMNPlane_test\" bpmnElement=\"test\" />\n                </bpmndi:BPMNDiagram>\n                </definitions>\n            ";
            // setTimeout(() => {
            this._bpmnModeler.importXML(initXml, function (err) {
                if (err) {
                    return console.error('could not import BPMN 2.0 diagram', err);
                }
                _this._canvas = _this._bpmnModeler.get('canvas');
                // zoom to fit full viewport
                // zoom to fit full viewport
                _this._canvas.zoom('fit-viewport');
            });
            // }, 2000)
        }
        else if (this.model.params.type == "edit") {
            // debugger
            if (this._bpmnModeler == undefined) {
                // create modeler
                this._bpmnModeler = new BpmnModeler$$1({
                    container: canvas,
                    zoomScroll: { enabled: false },
                    propertiesPanel: {
                        parent: '#js-properties-panel'
                    },
                    additionalModules: [
                        propertiesPanelModule$$1,
                        propertiesProviderModule$$1
                    ],
                    moddleExtensions: {
                        // camunda: camundaModdleDescriptor.CamundaModdleDescriptor
                        camunda: CamundaModdleDescriptor
                    }
                });
            }
            this.euBpmnService.getModelInfo(this.model.params.processDefId).then(function (data) {
                _this.model.bpmnModel = data.model;
                var /** @type {?} */ xml = _this.euBpmnService.activitiToCamundaAdapt(data.bpmn2xml);
                // setTimeout(() => {
                // setTimeout(() => {
                _this._bpmnModeler.importXML(xml, function (err) {
                    if (err) {
                        return console.error('could not import BPMN 2.0 diagram', err);
                    }
                    _this._canvas = _this._bpmnModeler.get('canvas');
                    // zoom to fit full viewport
                    // zoom to fit full viewport
                    _this._canvas.zoom('fit-viewport');
                });
                // }, 1500)
            });
            // this.http.get("workflow/model/editProcessByConvert/" + this.model.params.processDefId).toPromise().then(rep => {
            //     let rjson = rep.json();
            //     this.model.bpmnModel = rjson.model;
            //     let xml = this.activitiToCamundaAdapt(rjson.bpmn2xml)
            //     console.info('diagram geted');
            //     console.info(xml);
            //     setTimeout(() => {
            //         this._bpmnModeler.importXML(xml, (err) => {
            //             if (err) {
            //                 return console.error('could not import BPMN 2.0 diagram', err);
            //             }
            //             var canvas = this._bpmnModeler.get('canvas');
            //             // zoom to fit full viewport
            //             canvas.zoom('fit-viewport');
            //         });
            //     }, 1500)
            // })
        }
        else if (this.model.params.type == "config") {
            if (this._bpmnModeler == undefined) {
                // create modeler
                this._bpmnModeler = new BpmnViewer$$1({
                    container: canvas,
                });
            }
            this.euBpmnService.getProcessDefDiagramXml(this.model.params.processDefId).then(function (data) {
                setTimeout(function () {
                    _this._bpmnModeler.importXML(data, function (err) {
                        if (err) {
                            return console.error('could not import BPMN 2.0 diagram', err);
                        }
                        _this._canvas = _this._bpmnModeler.get('canvas');
                        // zoom to fit full viewport
                        // zoom to fit full viewport
                        _this._canvas.zoom('fit-viewport');
                    });
                }, 800);
            });
            // this.getProcessDefDiagram(this.model.params.processDefId).then(
            //     data => {
            //         setTimeout(() => {
            //             this._bpmnModeler.importXML(data, (err) => {
            //                 if (err) {
            //                     return console.error('could not import BPMN 2.0 diagram', err);
            //                 }
            //                 var canvas = this._bpmnModeler.get('canvas');
            //                 // zoom to fit full viewport
            //                 canvas.zoom('fit-viewport');
            //             });
            //         }, 800)
            //     }
            // )
            this.initConfigListener();
        }
    };
    /**
     * @param {?} processDefinitionId
     * @return {?}
     */
    BpmnEditorComponent.prototype.getProcessDefDiagram = /**
     * @param {?} processDefinitionId
     * @return {?}
     */
    function (processDefinitionId) {
        var /** @type {?} */ urlSearchParams = new HttpParams();
        urlSearchParams.set('processDefinitionId', processDefinitionId);
        var /** @type {?} */ headers = new HttpHeaders({ 'Content-Type': 'application/json;charset=UTF-8' });
        // private _getprocessdefdiagramUrl = "/process-definition/{processDefinitionId}/diagram-layout"
        return this.http.get('workflow/service/process-definition/' + processDefinitionId + '/diagram-layout', {
            params: urlSearchParams,
            headers: headers
        })
            .toPromise()
            .then(function (data) {
            return data;
        });
    };
    /**
     * @return {?}
     */
    BpmnEditorComponent.prototype.getBpmnModelerOrViewer = /**
     * @return {?}
     */
    function () {
    };
    /**
     * @return {?}
     */
    BpmnEditorComponent.prototype.saveModel = /**
     * @return {?}
     */
    function () {
        var _this = this;
        // let _this = this;
        return new Promise(function (resolve, reject) {
            _this._bpmnModeler.saveXML({ format: true }, function (err, xml) {
                if (err) {
                    console.error('diagram save failed', err);
                    reject(err);
                }
                else {
                    _this._bpmnModeler.saveSVG({ format: true }, function (err, svg) {
                        xml = _this.euBpmnService.camundaToActivitiAdapt(xml);
                        console.info('diagram saved');
                        console.info(xml);
                        _this.euBpmnService.saveModel(_this.model.bpmnModel.id, xml, svg);
                        // let body =
                        //     "xml=" + xml + "&" +
                        //     "svg=" + svg
                        // let headers = new Headers({ 'Content-Type': 'application/x-www-form-urlencoded;charset=ISO-8859-1' });
                        // let options = new RequestOptions({ headers: headers });
                        // this.http.put("workflow/service/model/" + this.model.bpmnModel.id + "/save", body, options)
                        //     .toPromise()
                        //     .then(function (response) {
                        //         console.log("response", response.json());
                        //         resolve(response.json())
                        //     })
                    });
                }
            });
            resolve("true");
        });
    };
    /**
     * @param {?} action
     * @return {?}
     */
    BpmnEditorComponent.prototype.onModalAction = /**
     * @param {?} action
     * @return {?}
     */
    function (action) {
        if (action.key == "close") {
            return this.saveModel();
            // return new Promise((resolve, reject) => {
            //     resolve("true");
            // });
        }
        else if (action.key == "dismiss") {
        }
    };
    /**
     * @return {?}
     */
    BpmnEditorComponent.prototype.resetZoom = /**
     * @return {?}
     */
    function () {
        this._canvas.zoom('fit-viewport');
        // this._bpmnModeler.get("zoomScroll").reset()
    };
    /**
     * @return {?}
     */
    BpmnEditorComponent.prototype.zoomUp = /**
     * @return {?}
     */
    function () {
        this._bpmnModeler.get("zoomScroll").stepZoom(1);
    };
    /**
     * @return {?}
     */
    BpmnEditorComponent.prototype.zoomDown = /**
     * @return {?}
     */
    function () {
        this._bpmnModeler.get("zoomScroll").stepZoom(-1);
    };
    BpmnEditorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'bpmn-editor',
                    template: "<!-- element to draw bpmn diagram in --> <div class=\"modeler\" style=\"height:650px\"> <div id=\"js-canvas\" style=\"height:100%\"></div> <div id=\"js-properties-panel\"></div> <!--<button id=\"save-button\" (click)=\"saveModel()\">保存</button>--> </div> <div class=\"io-zoom-controls\"> <ul class=\"io-zoom-reset io-control io-control-list\"> <li> <button title=\"reset zoom\" (click)=\"resetZoom()\"> <span class=\"icon-size-reset\"></span> </button> </li> </ul> <ul class=\"io-zoom io-control io-control-list\"> <li> <button title=\"zoom in\" (click)=\"zoomUp()\"> <span class=\"icon-plus\"></span> </button> </li> <li> <hr> </li> <li> <button href=\"\" title=\"zoom out\" (click)=\"zoomDown()\"> <span class=\"icon-minus\"></span> </button> </li> </ul> </div>",
                    styles: ["/* @import \"./assets/diagram-js.css\"; @import \"./assets/bpmn-app.css\"; @import \"./assets/diagram-js.css\"; @import \"./assets/bpmn-font/css/bpmn-embedded.css\"; */ [class^=\"bpmn-icon-\"]:before, [class*=\" bpmn-icon-\"]:before { margin-left: 0; } .io-zoom-controls { width: auto; position: absolute; right: 270px; bottom: 60px } .io-zoom-reset { margin-bottom: 10px; } .io-control-list { list-style: none; padding: 5px; margin: 0; } .bjs-powered-by, .cjs-powered-by, .io-control { background: #FFF; box-shadow: 0 1px 4px rgba(0,0,0,0.3); border-radius: 2px; padding: 5px; } .io-control-list a, .io-control-list a:visited, .io-control-list button { padding: 0; outline: none; cursor: pointer; font-size: 22px; line-height: 26px; color: #555555; background: none; border: none; } .io-control-list a, .io-control-list a:visited, .io-control-list button { padding: 0; outline: none; cursor: pointer; font-size: 22px; line-height: 26px; color: #555555; background: none; border: none; } .icon-size-reset:before { /*inline-resouce的时候 \f需要转义 下同*/         content: '\\f41f'; } [class^=\"icon-\"]:before, [class*=\" icon-\"]:before { font-family: \"app\"; } [class^=\"icon-\"]:before, [class*=\" icon-\"]:before, [class^=\"bpmn-icon-\"]:before, [class*=\" bpmn-icon-\"]:before { font-style: normal; font-weight: normal; speak: none; display: inline-block; text-decoration: inherit; width: 1em; text-align: center; font-variant: normal; text-transform: none; line-height: 1em; } .icon-plus:before {    content: '\\f417'; } .icon-minus:before { content: '\\f419'; } /* @font-face { font-family: 'app'; //    src: url('./assets/app-font/app.eot?42391129'); src: url('./assets/app-font/app.woff?42391129') format('woff'); font-weight: normal; font-style: normal } */ .io-zoom-reset { margin-bottom: 10px; }"],
                    encapsulation: ViewEncapsulation.None
                },] },
    ];
    // CamundaArray = {
    //     activiti: ["activiti:collection", "activiti:candidateUsers", "activiti:elementVariable"],
    //     camunda: ["camunda:collection", "camunda:candidateUsers", "camunda:elementVariable"]
    // }
    // activitiToCamundaAdapt(activitiXml: string): string {
    //     this.CamundaArray.activiti.forEach((str, index) => {
    //         var reg = "/" + str + "/ig";
    //         activitiXml = activitiXml.replace(eval(reg), this.CamundaArray.camunda[index]);
    //     })
    //     return activitiXml
    // }
    // camundaToActivitiAdapt(camundaXml: string): string {
    //     this.CamundaArray.camunda.forEach((str, index) => {
    //         var reg = "/" + str + "/ig";
    //         camundaXml = camundaXml.replace(eval(reg), this.CamundaArray.activiti[index]);
    //     })
    //     return camundaXml
    // }
    /** @nocollapse */
    BpmnEditorComponent.ctorParameters = function () { return [
        { type: HttpClient, },
        { type: EuBpmnService, },
    ]; };
    BpmnEditorComponent.propDecorators = {
        "model": [{ type: Input },],
    };
    return BpmnEditorComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var BpmnViewerComponent = (function () {
    function BpmnViewerComponent(http, vcRef, componentFactoryResolver) {
        this.http = http;
        this.vcRef = vcRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.$model = {
            params: {}
        };
        this._modalContext = {
            vcRef: vcRef,
            componentFactoryResolver: componentFactoryResolver
        };
    }
    /**
     * @return {?}
     */
    BpmnViewerComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        if (this.$model.params.processDefId != undefined
            && this.$model.params.processInsId != undefined) {
            this._dataUrl = "/workflow/monitor/wfmonitor?processInstanceId=" + this.$model.params.processInsId;
            // (require as any).ensure([], require => {
            //     let BpmnModeler = require('bpmn-js/lib/Modeler')
            //     let BpmnViewer = require('bpmn-js/lib/Viewer')
            //     let propertiesPanelModule = require('bpmn-js-properties-panel')
            //     let propertiesProviderModule = require('bpmn-js-properties-panel/lib/provider/camunda')
            //     this.initBpmn(BpmnModeler, BpmnViewer, propertiesPanelModule, propertiesProviderModule)
            // });
            this.initBpmn(BpmnModeler__default, BpmnViewer__default, propertiesPanelModule__default, propertiesProviderModule__default);
        }
    };
    /**
     * @param {?} BpmnModeler
     * @param {?} BpmnViewer
     * @param {?} propertiesPanelModule
     * @param {?} propertiesProviderModule
     * @return {?}
     */
    BpmnViewerComponent.prototype.initBpmn = /**
     * @param {?} BpmnModeler
     * @param {?} BpmnViewer
     * @param {?} propertiesPanelModule
     * @param {?} propertiesProviderModule
     * @return {?}
     */
    function (BpmnModeler$$1, BpmnViewer$$1, propertiesPanelModule$$1, propertiesProviderModule$$1) {
        var _this = this;
        if ((this.$model.params.processDefId == undefined && this.$model.params.processInsId == undefined)) {
            // toastr.warning('没有流程信息')
            return;
        }
        // var windowl: any = window
        // var propertiesPanelModule = windowl.PropertiesPanelModule;
        // var propertiesProviderModule = windowl.PropertiesProviderModule;
        // var camundaModdleDescriptor = require("./camunda")
        // var BpmnModeler = windowl.BpmnJS;
        // var BpmnViewer = windowl.BpmnViewer;
        // var canvas = $('#js-canvas-view');
        var /** @type {?} */ canvas = document.querySelectorAll('#js-canvas-view');
        if (this.$model.params.type == "view") {
            if (this._bpmnModeler == undefined) {
                // create modeler
                this._bpmnModeler = new BpmnViewer$$1({
                    container: canvas,
                });
            }
            // let eventBus = this._bpmnModeler.get('eventBus')
            // this._bpmnModeler.on('canvas.init', 1000, function () {
            //     debugger
            //     $('path').each(function (e) {
            //         var path = $(this);
            //         var style = path.attr('style');
            //         if (style) {
            //             path.attr('style', style.replace(/url\("#/g, 'url("' + location.href + '#'));
            //         }
            //     });
            // });
            var /** @type {?} */ forkTask = [
                this.getHighLights(this.$model.params.processInsId),
                this.getProcessDefDiagram(this.$model.params.processDefId)
            ];
            Observable.forkJoin(forkTask).subscribe(function (data) {
                // var defs = document.getElementsByTagName('defs')[0];
                // let makerHtml = $.parseHTML('<marker viewBox="0 0 20 20" markerWidth="10" markerHeight="10" orient="auto" refX="11" refY="10" id="markerSiuwuemg141"><path d="M 1 5 L 11 10 L 1 15 Z" fill="#000000" style="stroke-width: 1; stroke-linecap: round; stroke-dasharray: 10000, 1;"></path></marker>')
                // defs.appendChild(makerHtml[0]);
                var /** @type {?} */ highlights = data[0];
                var /** @type {?} */ xml = data[1];
                setTimeout(function () {
                    _this._bpmnModeler.importXML(xml, function (err) {
                        if (err) {
                            return console.error('could not import BPMN 2.0 diagram', err);
                        }
                        var /** @type {?} */ canvas = _this._bpmnModeler.get('canvas');
                        var /** @type {?} */ svg = canvas._svg;
                        // 绿色三角的箭头
                        // 绿色三角的箭头
                        _this.addMarker('greenendmark-end-white-black', {}, canvas);
                        // this.addGreenEndMarker()
                        // $('path').each(function (e) {
                        //     var path = $(this);
                        //     var style = path.attr('style');
                        //     if (style) {
                        //         // debugger
                        //         if (path) {
                        //             path.attr('style', style.replace(/url\("#/g, 'url("' + location.href + '#'));
                        //         }
                        //         // path.attr('style', style.replace(/url\("#/g, 'url("' + 'workflow/usertaskdo' + '#'));
                        //         // path.attr('style', style.replace(/url\("#\w*/g, 'url("' + location.href + '#greenendmark'));
                        //     }
                        // });
                        var /** @type {?} */ activitiesExecuted = highlights.activitiesExecuted;
                        var /** @type {?} */ activities = highlights.activities;
                        var /** @type {?} */ flows = highlights.flows;
                        // let r = $("g.djs-connection").each(function (e) {
                        // let r = document.querySelectorAll("g.djs-connection").each(function (e) {
                        //     var g = $(this)
                        //     var path = g.find('path')
                        //     var style = path.attr('style')
                        //     var flow_id = g.attr('data-element-id')
                        //     if (flows.includes(flow_id)) {
                        //         path.attr('style', style.replace(/url\("#\w*/g, 'url("' + location.href + '#greenendmark'))
                        //     } else {
                        //         path.attr('style', style.replace(/url\("#/g, 'url("' + location.href + '#'));
                        //     }
                        // })
                        each(activitiesExecuted, function (v, i) {
                            canvas.addMarker(v, 'highlightgreen');
                        });
                        each(activities, function (v, i) {
                            canvas.addMarker(v, 'highlightred');
                        });
                        each(flows, function (v, i) {
                            canvas.addMarker(v, 'highlightflowgreen');
                        });
                        // zoom to fit full viewport
                        canvas.zoom('fit-viewport');
                    });
                }, 800);
            });
        }
    };
    /**
     * 绿色的箭头，可以在path的style中用url链过来
     * @param id
     * @param options
     * @param canvas
     */
    /**
     * 绿色的箭头，可以在path的style中用url链过来
     * @param {?} id
     * @param {?} options
     * @param {?} canvas
     * @return {?}
     */
    BpmnViewerComponent.prototype.addMarker = /**
     * 绿色的箭头，可以在path的style中用url链过来
     * @param {?} id
     * @param {?} options
     * @param {?} canvas
     * @return {?}
     */
    function (id, options, canvas) {
        var /** @type {?} */ attrs = assign({
            fill: '#00ff00',
            strokeWidth: 1,
            strokeLinecap: 'round',
            strokeDasharray: 'none'
        }, options.attrs);
        var /** @type {?} */ ref = options.ref || { x: 11, y: 10 };
        var /** @type {?} */ scale = options.scale || 0.5;
        // fix for safari / chrome / firefox bug not correctly
        // resetting stroke dash array
        if (attrs.strokeDasharray === 'none') {
            attrs.strokeDasharray = [10000, 1];
        }
        var /** @type {?} */ marker = svgCreate('marker');
        if (!options.element) {
            options.element = svgCreate('path');
            svgAttr(options.element, { d: 'M 1 5 L 11 10 L 1 15 Z' });
        }
        svgAttr(options.element, attrs);
        svgAppend(marker, options.element);
        svgAttr(marker, {
            id: id,
            viewBox: '0 0 20 20',
            refX: ref.x,
            refY: ref.y,
            markerWidth: 20 * scale,
            markerHeight: 20 * scale,
            orient: 'auto'
        });
        var /** @type {?} */ defs = domQuery('defs', canvas._svg);
        if (!defs) {
            defs = svgCreate('defs');
            svgAppend(canvas._svg, defs);
        }
        svgAppend(defs, marker);
        // markers[id] = marker;
    };
    /**
     * 绿色的箭头，可以在path的style中用url链过来
     * @param svg
     *
     */
    /**
     * 绿色的箭头，可以在path的style中用url链过来
     * @return {?}
     */
    BpmnViewerComponent.prototype.addGreenEndMarker = /**
     * 绿色的箭头，可以在path的style中用url链过来
     * @return {?}
     */
    function () {
        /**
         * @param {?} id
         * @param {?} options
         * @return {?}
         */
        function createMarker(id, options) {
            var /** @type {?} */ attrs = assign({
                fill: '#00ff00',
                strokeWidth: 1,
                strokeLinecap: 'round',
                strokeDasharray: 'none'
            }, options.attrs);
            var /** @type {?} */ ref = options.ref || { x: 0, y: 0 };
            var /** @type {?} */ scale = options.scale || 1;
            // fix for safari / chrome / firefox bug not correctly
            // resetting stroke dash array
            if (attrs.strokeDasharray === 'none') {
                attrs.strokeDasharray = [10000, 1];
            }
            var /** @type {?} */ marker = options.element
                .attr(attrs)
                .marker(0, 0, 20, 20, ref.x, ref.y)
                .attr({
                markerWidth: 20 * scale,
                markerHeight: 20 * scale,
                id: "greenendmark"
            });
            // return addMarker(id, marker);
        }
        var /** @type {?} */ path = svgCreate('path');
        svgAttr(path, { d: 'M 1 5 L 11 10 L 1 15 Z' });
        createMarker('sequenceflow-end', {
            // element: svg.path('M 1 5 L 11 10 L 1 15 Z'),
            element: path,
            ref: { x: 11, y: 10 },
            scale: 0.5
        });
    };
    /**
     * @param {?} processInstanceId
     * @return {?}
     */
    BpmnViewerComponent.prototype.getHighLights = /**
     * @param {?} processInstanceId
     * @return {?}
     */
    function (processInstanceId) {
        var /** @type {?} */ url = "workflow/service/process-instance/" + processInstanceId + "/highlights";
        var /** @type {?} */ urlSearchParams = new URLSearchParams();
        var /** @type {?} */ headers = new Headers({ 'Content-Type': 'application/json;charset=UTF-8' });
        var /** @type {?} */ options = new RequestOptions({
            headers: headers,
            search: urlSearchParams
        });
        return this.http.get(url, options)
            .toPromise()
            .then(function (data) {
            return data.json();
        });
    };
    /**
     * @param {?} processDefinitionId
     * @return {?}
     */
    BpmnViewerComponent.prototype.getProcessDefDiagram = /**
     * @param {?} processDefinitionId
     * @return {?}
     */
    function (processDefinitionId) {
        var /** @type {?} */ urlSearchParams = new URLSearchParams();
        urlSearchParams.set('processDefinitionId', processDefinitionId);
        var /** @type {?} */ headers = new Headers({ 'Content-Type': 'application/json;charset=UTF-8' });
        var /** @type {?} */ options = new RequestOptions({
            headers: headers,
            search: urlSearchParams
        });
        // private _getprocessdefdiagramUrl = "/process-definition/{processDefinitionId}/diagram-layout"
        return this.http.get('workflow/service/process-definition/' + processDefinitionId + '/diagram-layout', options)
            .toPromise()
            .then(function (data) {
            return data.text();
        });
    };
    /**
     * @return {?}
     */
    BpmnViewerComponent.prototype.getBpmnModelerOrViewer = /**
     * @return {?}
     */
    function () {
    };
    /**
     * @param {?} action
     * @return {?}
     */
    BpmnViewerComponent.prototype.onModalAction = /**
     * @param {?} action
     * @return {?}
     */
    function (action) {
        if (action.key == "close") {
            // return new Promise((resolve, reject) => {
            //     resolve("true");
            // });
        }
        else if (action.key == "dismiss") {
        }
    };
    BpmnViewerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'bpmn-viewer',
                    styles: ['.highlight:not(.djs-connection) .djs-visual > :nth-child(1) {fill: green !important; /* color elements as green */}'],
                    template: "\n        <style>\n            .highlight{\n              fill: green !important; /* color elements as green */\n            }\n        </style>    \n        <div class=\"modeler\" style=\"height:480px\">\n          <div id=\"js-canvas-view\" style=\"height:100%\"></div>\n          <div id=\"js-properties-panel\"></div>\n        </div>\n    "
                },] },
    ];
    // CamundaArray = {
    //     activiti: ["activiti:collection", "activiti:candidateUsers", "activiti:elementVariable"],
    //     camunda: ["camunda:collection", "camunda:candidateUsers", "camunda:elementVariable"]
    // }
    // activitiToCamundaAdapt(activitiXml: string): string {
    //     this.CamundaArray.activiti.forEach((str, index) => {
    //         var reg = "/" + str + "/ig";
    //         activitiXml = activitiXml.replace(eval(reg), this.CamundaArray.camunda[index]);
    //     })
    //     return activitiXml
    // }
    // camundaToActivitiAdapt(camundaXml: string): string {
    //     this.CamundaArray.camunda.forEach((str, index) => {
    //         var reg = "/" + str + "/ig";
    //         camundaXml = camundaXml.replace(eval(reg), this.CamundaArray.activiti[index]);
    //     })
    //     return camundaXml
    // }
    /** @nocollapse */
    BpmnViewerComponent.ctorParameters = function () { return [
        { type: Http, },
        { type: ViewContainerRef, },
        { type: ComponentFactoryResolver, },
    ]; };
    BpmnViewerComponent.propDecorators = {
        "$model": [{ type: Input },],
    };
    return BpmnViewerComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ModelInput = (function () {
    function ModelInput() {
    }
    return ModelInput;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EasyUIBpmnModule = (function () {
    function EasyUIBpmnModule() {
    }
    EasyUIBpmnModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                    ],
                    exports: [
                        BpmnEditorComponent,
                    ],
                    declarations: [
                        BpmnEditorComponent,
                        BpmnViewerComponent
                    ],
                    providers: [],
                    entryComponents: []
                },] },
    ];
    return EasyUIBpmnModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { EasyUIBpmnModule, BpmnEditorComponent, ModelInput, BpmnViewerComponent as ɵa };
//# sourceMappingURL=bpmn2.es5.js.map
