import { EventEmitter } from "@angular/core";
import { ModalConfig } from '../modal/modal-config';
import { BaseAction } from '../action';
export declare abstract class EuTree {
    check: EventEmitter<TreeEmitEvent>;
    decheck: EventEmitter<TreeEmitEvent>;
    toggleExpanded?: EventEmitter<TreeEmitEvent>;
    activate?: EventEmitter<TreeEmitEvent>;
    deactivate?: EventEmitter<TreeEmitEvent>;
    nodeActivate?: EventEmitter<TreeEmitEvent>;
    nodeDeactivate?: EventEmitter<TreeEmitEvent>;
    select: EventEmitter<TreeEmitEvent>;
    deselect: EventEmitter<TreeEmitEvent>;
    focus?: EventEmitter<TreeEmitEvent>;
    blur?: EventEmitter<TreeEmitEvent>;
    updateData?: EventEmitter<TreeEmitEvent>;
    initialized: EventEmitter<TreeEmitEvent>;
    moveNode?: EventEmitter<TreeEmitEvent>;
    copyNode?: EventEmitter<TreeEmitEvent>;
    loadNodeChildren?: EventEmitter<TreeEmitEvent>;
    changeFilter?: EventEmitter<TreeEmitEvent>;
    event?: EventEmitter<TreeEmitEvent>;
    stateChange?: EventEmitter<TreeEmitEvent>;
    abstract refresh(params: any, node?: EuTreeNode, openState?: any, checkState?: any, selectedState?: any): any;
    abstract refreshSelectedNode(): any;
    abstract refreshSelectedNodeParent(): any;
    abstract getNodeById(id: string): EuTreeNode;
    abstract getSelectedNode(): EuTreeNode;
    abstract getSelectedNodes(): Array<EuTreeNode>;
    abstract getCheckedNodes(checked?: boolean): Array<EuTreeNode>;
    abstract setSelectedNode(idOrNode: string | EuTreeNode, selected: boolean): any;
}
export interface TreeEmitEvent {
    name: string;
    tree?: EuTree;
    node?: EuTreeNode;
    nodes?: EuTreeNode[];
}
export declare abstract class EuTreeNode {
    children?: EuTreeNode[];
    id: string;
    sid?: number;
    name: string;
    hasChildren?: boolean;
    isExpanded?: boolean;
    parent?: EuTreeNode;
    originalNode?: any;
    [propName: string]: any;
}
export declare class TreeEvent {
    constructor(options: {
        businessId: string;
        action: TreeAction;
        activeEuNodes?: Array<EuTreeNode>;
        event?: any;
        selectedEuNodes?: Array<EuTreeNode>;
        data?: any;
    });
    activeEuNodes: Array<EuTreeNode>;
    selectedEuNodes?: Array<EuTreeNode>;
    businessId: string;
    action: TreeAction;
    data?: any;
}
export declare class TreeAction extends BaseAction {
    constructor(options: BaseAction);
}
export declare class EuTreeOptions {
    treeId: string;
    rootNodeName: string;
    dataUrl: string;
    actions?: Array<TreeAction>;
    defaultActionModalConfig: ModalConfig;
    params?: any;
    autoParam?: Array<string>;
    expendAll?: boolean;
    expendLevel?: number;
    selectedMulti?: boolean;
    nameIsHTML?: boolean;
    checkEnable?: boolean;
    checkStyle?: string;
    chkboxType?: any;
    autoCheckTrigger?: boolean;
    nodeCheck?: (tree: EuTree, node: EuTreeNode, $event) => void;
    nodeClick?: (tree: EuTree, node: EuTreeNode, $event) => void;
    otherOptions?: any;
    constructor(options?: {
        treeId: string;
        rootNodeName?: string;
        dataUrl: string;
        actions?: Array<TreeAction>;
        defaultActionModalConfig?: ModalConfig;
        nameIsHTML?: boolean;
        params?: any;
        autoParam?: Array<string>;
        expendAll?: boolean;
        expendLevel?: number;
        selectedMulti?: boolean;
        checkEnable?: boolean;
        checkStyle?: string;
        chkboxType?: any;
        autoCheckTrigger?: boolean;
        nodeCheck?: (tree: EuTree, node: EuTreeNode, $event) => void;
        nodeClick?: (tree: EuTree, node: EuTreeNode, $event) => void;
    });
}
